@@ -3,6 +3,7 @@ package WebGUI::Cache::CHI;
 use strict;
 use base 'WebGUI::Cache';
 use File::Temp qw/tempdir/;
+use Clone qw/clone/;
 use CHI;
 
 =head1 NAME
@@ -92,7 +93,7 @@ sub new {
     # Create CHI object from config
     my $chi;
     unless ( $chi = $session->stow->get( "CHI" ) ) {
-        my $cacheConf    = $session->config->get('cache');
+        my $cacheConf    = clone $session->config->get('cache');
         $cacheConf->{namespace}     = $namespace;
         $cacheConf->{is_size_aware} = 1;
 
